@@ -752,17 +752,17 @@ class WordToken(caching.base.CachingMixin,models.Model):
 
     def getPreviousWord(self):
         if self.DialogPart == 'b' and self.Begin == 0.0:
-            prev = WordToken.objects.select_related('Category').filter(Dialog=self.Dialog).filter(DialogPart='a').order_by('-Begin')
+            prev = WordToken.objects.select_related('Category','WordType').filter(Dialog=self.Dialog).filter(DialogPart='a').order_by('-Begin')
         else:
-            prev = WordToken.objects.select_related('Category').filter(Dialog=self.Dialog).filter(pk=self.pk-1)
+            prev = WordToken.objects.select_related('Category','WordType').filter(Dialog=self.Dialog).filter(pk=self.pk-1)
         if len(prev) > 0:
             return prev[0]
         return None
 
     def getFollowingWord(self):
-        foll = WordToken.objects.select_related('Category').filter(Dialog=self.Dialog).filter(pk=self.pk+1)
+        foll = WordToken.objects.select_related('Category','WordType').filter(Dialog=self.Dialog).filter(pk=self.pk+1)
         if self.DialogPart == 'a' and len(foll) == 0:
-            foll = WordToken.objects.select_related('Category').filter(Dialog=self.Dialog).filter(DialogPart='b').filter(Begin__exact=0.0)
+            foll = WordToken.objects.select_related('Category','WordType').filter(Dialog=self.Dialog).filter(DialogPart='b').filter(Begin__exact=0.0)
         if len(foll) > 0:
             return foll[0]
         return None
